==> dojo-1.9.4.tgz: package/cldr/nls/ar/japanese.js <==
define(
//begin v1.x content
{
	"field-second": "الثواني",
	"field-year-relative+-1": "السنة الماضية",
	"field-week": "الأسبوع",
	"field-month-relative+-1": "الشهر الماضي",
	"field-day-relative+-1": "أمس",
	"field-day-relative+-2": "أول أمس",
	"field-year": "السنة",
	"field-week-relative+0": "هذا الأسبوع",
	"field-week-relative+1": "الأسبوع التالي",
	"field-minute": "الدقائق",
	"field-week-relative+-1": "الأسبوع الماضي",
	"field-day-relative+0": "اليوم",
	"field-hour": "الساعات",
	"field-day-relative+1": "غدًا",
	"field-day-relative+2": "بعد الغد",
	"field-day": "يوم",
	"field-month-relative+0": "هذا الشهر",
	"field-month-relative+1": "الشهر التالي",
	"field-dayperiod": "ص/م",
	"field-month": "الشهر",
	"field-era": "العصر",
	"field-year-relative+0": "هذه السنة",
	"field-year-relative+1": "السنة التالية",
	"eraAbbr": [
		"تيكا",
		"هاكتشي",
		"هاكهو",
		"شتشو",
		"تيهو",
		"كيين",
		"وادو",
		"رييكي",
		"يورو",
		"جينكي",
		"تمبيو",
		"تمبيو-كامبو",
		"تمبيو-شوهو",
		"تمبيو-هوجي",
		"تمفو-جينجو",
		"جينجو-كيين",
		"هوكي",
		"تن-أو",
		"إنرياكو",
		"ديدو",
		"كونين",
		"تنتشو",
		"شووا (٨٣٤–٨٤٨)‏",
		"كاجو",
		"نينجو",
		"سيكو",
		"تنان",
		"جوجان",
		"جينكيي",
		"نينا",
		"كامبيو",
		"شوتاي",
		"انجي",
		"انتشو",
		"شوهيي",
		"تنجيو",
		"تنرياكو",
		"تنتوكو",
		"أووا",
		"كوهو",
		"آنا",
		"تينروكو",
		"تن-ان",
		"جوجن",
		"تنجن",
		"إيكان",
		"كانا",
		"اي-ان",
		"ايسو",
		"شورياكو (٩٩٠–٩٩٥)‏",
		"تشوتوكو",
		"تشوهو",
		"كانكو",
		"تشووا",
		"كانين",
		"جاين",
		"مانجو",
		"تشوجين",
		"تشورياكو",
		"تشوكيو (١٠٤٠–١٠٤٤)‏",
		"كانتوكو",
		"ايشو (١٠٤٦–١٠٥٣)‏",
		"تينجي",
		"كوهيي",
		"جيرياكو",
		"انكيو (١٠٦٩–١٠٧٤)‏",
		"شوهو (١٠٧٤–١٠٧٧)‏",
		"شورياكو (١٠٧٧–١٠٨١)‏",
		"ايهو",
		"أوتوكو",
		"كانجي",
		"كاهو",
		"ايتشو",
		"شوتوكو",
		"كووا (١٠٩٩–١١٠٤)‏",
		"تشوجي",
		"كاشو",
		"تنين",
		"تن-اي",
		"ايكيو (١١١٣–١١١٨)‏",
		"جن-اي",
		"هوان",
		"تنجي",
		"ديجي",
		"تنشو (١١٣١–١١٣٢)‏",
		"تشوشو",
		"هوين",
		"ايجي",
		"كوجي (١١٤٢–١١٤٤)‏",
		"تنيو",
		"كيوان",
		"نينبيي",
		"كيوجو",
		"هجين",
		"هيجي",
		"ايرياكو",
		"أوهو",
		"تشوكان",
		"ايمان",
		"نين-ان",
		"كاو",
		"شون",
		"أنجين",
		"جيشو",
		"يووا",
		"جيي",
		"جنريوكو",
		"بنجي",
		"كنكيو",
		"شوجي",
		"كنين",
		"جنكيو (١٢٠٤–١٢٠٦)‏",
		"كن-اي",
		"شوجن (١٢٠٧–١٢١١)‏",
		"كنرياكو",
		"كنبو (١٢١٣–١٢١٩)‏",
		"شوكيو",
		"جو",
		"جيننين",
		"كروكو",
		"أنتيي",
		"كنكي",
		"جويي",
		"تمبكو",
		"بنرياكو",
		"كاتيي",
		"رياكنين",
		"ان-أو",
		"نينجي",
		"كنجين",
		"هوجي",
		"كنتشو",
		"كوجن",
		"شوكا",
		"شوجن (١٢٥٩–١٢٦٠)‏",
		"بن-أو",
		"كوتشو",
		"بن-اي",
		"كنجي",
		"كوان",
		"شوو (١٢٨٨–١٢٩٣)‏",
		"اينين",
		"شوان",
		"كنجن",
		"كجن",
		"توكجي",
		"انكي",
		"أوتشو",
		"شووا (١٣١٢–١٣١٧)‏",
		"بنبو",
		"جنو",
		"جنكيو (١٣٢١–١٣٢٤)‏",
		"شوتشو (١٣٢٤–١٣٢٦)‏",
		"كريكي",
		"جنتكو",
		"جنكو",
		"كمو",
		"إنجن",
		"كوككو",
		"شوهي",
		"كنتكو",
		"بنتشو",
		"تنجو",
		"كورياكو",
		"كووا (١٣٨١–١٣٨٤)‏",
		"جنتشو",
		"مييتكو (١٣٨٤–١٣٨٧)‏",
		"كاكي",
		"كو",
		"مييتكو (١٣٩٠–١٣٩٤)‏",
		"أويي",
		"شوتشو (١٤٢٨–١٤٢٩)‏",
		"ايكيو (١٤٢٩–١٤٤١)‏",
		"ككيتسو",
		"بن-أن",
		"هوتكو",
		"كيوتكو",
		"كوشو",
		"تشوركو",
		"كنشو",
		"بنشو",
		"أونين",
		"بنمي",
		"تشوكيو (١٤٨٧–١٤٨٩)‏",
		"انتكو",
		"ميو",
		"بنكي",
		"ايشو (١٥٠٤–١٥٢١)‏",
		"تييي",
		"كيوركو",
		"تنمن",
		"كوجي (١٥٥٥–١٥٥٨)‏",
		"ايركو",
		"جنكي",
		"تنشو (١٥٧٣–١٥٩٢)‏",
		"بنركو",
		"كيتشو",
		"جنوا",
		"كان-اي",
		"شوهو (١٦٤٤–١٦٤٨)‏",
		"كيان",
		"شوو (١٦٥٢–١٦٥٥)‏",
		"ميرياكو",
		"منجي",
		"كنبن",
		"انبو",
		"تنوا",
		"جوكيو",
		"جنركو",
		"هويي",
		"شوتكو",
		"كيوهو",
		"جنبن",
		"كنبو (١٧٤١–١٧٤٤)‏",
		"انكيو (١٧٤٤–١٧٤٨)‏",
		"كان-ان",
		"هورياكو",
		"مييوا",
		"ان-اي",
		"تنمي",
		"كنسي",
		"كيووا",
		"بنكا",
		"بنسي",
		"تنبو",
		"كوكا",
		"كاي",
		"أنسي",
		"من-ان",
		"بنكيو",
		"جنجي",
		"كيو",
		"ميجي",
		"تيشو",
		"شووا",
		"هيسي"
	],
	"field-weekday": "اليوم",
	"field-zone": "التوقيت"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/ar/japanese.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "السبت الحالي",
	"field-sat-relative+1": "السبت التالي",
	"field-dayperiod": "ص/م",
	"field-sun-relative+-1": "الأحد الماضي",
	"field-mon-relative+-1": "الاثنين الماضي",
	"field-minute": "الدقائق",
	"field-day-relative+-1": "أمس",
	"field-weekday": "اليوم",
	"field-day-relative+-2": "أول أمس",
	"field-era": "العصر",
	"field-hour": "الساعات",
	"field-sun-relative+0": "الأحد الحالي",
	"field-sun-relative+1": "الأحد التالي",
	"field-wed-relative+-1": "الأربعاء الماضي",
	"field-day-relative+0": "اليوم",
	"field-day-relative+1": "غدًا",
	"eraAbbr": [
		"تيكا",
		"هاكتشي",
		"هاكهو",
		"شتشو",
		"تيهو",
		"كيين",
		"وادو",
		"رييكي",
		"يورو",
		"جينكي",
		"تمبيو",
		"تمبيو-كامبو",
		"تمبيو-شوهو",
		"تمبيو-هوجي",
		"تمفو-جينجو",
		"جينجو-كيين",
		"هوكي",
		"تن-أو",
		"إنرياكو",
		"ديدو",
		"كونين",
		"تنتشو",
		"شووا (٨٣٤–٨٤٨)‏",
		"كاجو",
		"نينجو",
		"سيكو",
		"تنان",
		"جوجان",
		"جينكيي",
		"نينا",
		"كامبيو",
		"شوتاي",
		"انجي",
		"انتشو",
		"شوهيي",
		"تنجيو",
		"تنرياكو",
		"تنتوكو",
		"أووا",
		"كوهو",
		"آنا",
		"تينروكو",
		"تن-نن",
		"جوجن",
		"تنجن",
		"إيكان",
		"كانا",
		"اي-ان",
		"ايسو",
		"شورياكو (٩٩٠–٩٩٥)‏",
		"تشوتوكو",
		"تشوهو",
		"كانكو",
		"تشووا",
		"كانين",
		"جاين",
		"مانجو",
		"تشوجين",
		"تشورياكو",
		"تشوكيو (١٠٤٠–١٠٤٤)‏",
		"كانتوكو",
		"ايشو (١٠٤٦–١٠٥٣)‏",
		"تينجي",
		"كوهيي",
		"جيرياكو",
		"انكيو (١٠٦٩–١٠٧٤)‏",
		"شوهو (١٠٧٤–١٠٧٧)‏",
		"شورياكو (١٠٧٧–١٠٨١)‏",
		"ايهو",
		"أوتوكو",
		"كانجي",
		"كاهو",
		"ايتشو",
		"شوتوكو",
		"كووا (١٠٩٩–١١٠٤)‏",
		"تشوجي",
		"كاشو",
		"تنين",
		"تن-اي",
		"ايكيو (١١١٣–١١١٨)‏",
		"جن-اي",
		"هوان",
		"تنجي",
		"ديجي",
		"تنشو (١١٣١–١١٣٢)‏",
		"تشوشو",
		"هوين",
		"ايجي",
		"كوجي (١١٤٢–١١٤٤)‏",
		"تنيو",
		"كيوان",
		"نينبيي",
		"كيوجو",
		"هجين",
		"هيجي",
		"ايرياكو",
		"أوهو",
		"تشوكان",
		"ايمان",
		"نين-ان",
		"كاو",
		"شون",
		"أنجين",
		"جيشو",
		"يووا",
		"جيي",
		"جنريوكو",
		"بنجي",
		"كنكيو",
		"شوجي",
		"كنين",
		"جنكيو (١٢٠٤–١٢٠٦)‏",
		"كن-اي",
		"شوجن (١٢٠٧–١٢١١)‏",
		"كنرياكو",
		"كنبو (١٢١٣–١٢١٩)‏",
		"شوكيو",
		"جو",
		"جيننين",
		"كروكو",
		"أنتيي",
		"كنكي",
		"جويي",
		"تمبكو",
		"بنرياكو",
		"كاتيي",
		"رياكنين",
		"ان-أو",
		"نينجي",
		"كنجين",
		"هوجي",
		"كنتشو",
		"كوجن",
		"شوكا",
		"شوجن (١٢٥٩–١٢٦٠)‏",
		"بن-أو",
		"كوتشو",
		"بن-اي",
		"كنجي",
		"كوان",
		"شوو (١٢٨٨–١٢٩٣)‏",
		"اينين",
		"شوان",
		"كنجن",
		"كجن",
		"توكجي",
		"انكي",
		"أوتشو",
		"شووا (١٣١٢–١٣١٧)‏",
		"بنبو",
		"جنو",
		"جنكيو (١٣٢١–١٣٢٤)‏",
		"شوتشو (١٣٢٤–١٣٢٦)‏",
		"كريكي",
		"جنتكو",
		"جنكو",
		"كمو",
		"إنجن",
		"كوككو",
		"شوهي",
		"كنتكو",
		"بنتشو",
		"تنجو",
		"كورياكو",
		"كووا (١٣٨١–١٣٨٤)‏",
		"جنتشو",
		"مييتكو (١٣٨٤–١٣٨٧)‏",
		"كاكي",
		"كو",
		"مييتكو (١٣٩٠–١٣٩٤)‏",
		"أويي",
		"شوتشو (١٤٢٨–١٤٢٩)‏",
		"ايكيو (١٤٢٩–١٤٤١)‏",
		"ككيتسو",
		"بن-أن",
		"هوتكو",
		"كيوتكو",
		"كوشو",
		"تشوركو",
		"كنشو",
		"بنشو",
		"أونين",
		"بنمي",
		"تشوكيو (١٤٨٧–١٤٨٩)‏",
		"انتكو",
		"ميو",
		"بنكي",
		"ايشو (١٥٠٤–١٥٢١)‏",
		"تييي",
		"كيوركو",
		"تنمن",
		"كوجي (١٥٥٥–١٥٥٨)‏",
		"ايركو",
		"جنكي",
		"تنشو (١٥٧٣–١٥٩٢)‏",
		"بنركو",
		"كيتشو",
		"جنوا",
		"كان-اي",
		"شوهو (١٦٤٤–١٦٤٨)‏",
		"كيان",
		"شوو (١٦٥٢–١٦٥٥)‏",
		"ميرياكو",
		"منجي",
		"كنبن",
		"انبو",
		"تنوا",
		"جوكيو",
		"جنركو",
		"هويي",
		"شوتكو",
		"كيوهو",
		"جنبن",
		"كنبو (١٧٤١–١٧٤٤)‏",
		"انكيو (١٧٤٤–١٧٤٨)‏",
		"كان-ان",
		"هورياكو",
		"مييوا",
		"ان-اي",
		"تنمي",
		"كنسي",
		"كيووا",
		"بنكا",
		"بنسي",
		"تنبو",
		"كوكا",
		"كاي",
		"أنسي",
		"من-ان",
		"بنكيو",
		"جنجي",
		"كيو",
		"ميجي",
		"تيشو",
		"شووا",
		"هيسي"
	],
	"field-day-relative+2": "بعد الغد",
	"field-tue-relative+0": "الثلاثاء الحالي",
	"field-zone": "التوقيت",
	"field-tue-relative+1": "الثلاثاء التالي",
	"field-week-relative+-1": "الأسبوع الماضي",
	"field-year-relative+0": "السنة الحالية",
	"field-year-relative+1": "السنة التالية",
	"field-sat-relative+-1": "السبت الماضي",
	"field-year-relative+-1": "السنة الماضية",
	"field-year": "السنة",
	"field-fri-relative+0": "الجمعة الحالية",
	"field-fri-relative+1": "الجمعة التالية",
	"field-week": "الأسبوع",
	"field-week-relative+0": "هذا الأسبوع",
	"field-week-relative+1": "الأسبوع التالي",
	"field-month-relative+0": "هذا الشهر",
	"field-month": "الشهر",
	"field-month-relative+1": "الشهر التالي",
	"field-fri-relative+-1": "الجمعة الماضية",
	"field-second": "الثواني",
	"field-tue-relative+-1": "الثلاثاء الماضي",
	"field-day": "يوم",
	"field-mon-relative+0": "الاثنين الحالي",
	"field-mon-relative+1": "الاثنين التالي",
	"field-thu-relative+0": "الخميس الحالي",
	"field-second-relative+0": "الآن",
	"field-thu-relative+1": "الخميس التالي",
	"field-wed-relative+0": "الأربعاء الحالي",
	"field-wed-relative+1": "الأربعاء التالي",
	"field-month-relative+-1": "الشهر الماضي",
	"field-thu-relative+-1": "الخميس الماضي"
}
//end v1.x content
);
